/*
	SearchCommand
	version 1.0.0
	Created by Jesse R. Warden a.k.a. "JesterXL"
	jesterxl@jessewarden.com
	http://www.jessewarden.com
	
	This command class is run when the Controller intercepts a
	SearchBooksEvent.  Typically, the same Command can handle
	many events, and figure out how to handle them in the execute method.
	For now, this guy merely calls the Delegate's searchBook method,
	and when the data comes back, he updates the ModelLocator.
	
	Commands should ALWAYS be the ones setting ModelLocator.  View's shouldn't,
	nor should Delegate's.  There are times when it's ok for a View to do so,
	but you should be sure you couldn't do it in a Command instead.  View's
	should technically be "asking" the Controller via Events to change data.
	...yes, I know, this is a LOT of events.
	
	This is release under a Creative Commons license. More information can be
	found here:
	
	http://creativecommons.org/licenses/by/2.5/
*/
package com.jxl.amazon.commands
{
	
	import com.adobe.cairngorm.commands.Command;
	import com.adobe.cairngorm.business.Responder;
	import com.adobe.cairngorm.control.CairngormEvent;
	
	import com.jxl.amazon.events.SearchBooksEvent;
	
	import com.jxl.amazon.business.SearchDelegate;
	import mx.rpc.events.ResultEvent;
	import mx.rpc.events.FaultEvent;
	
	import com.jxl.amazon.model.ModelLocator;
	import mx.collections.ArrayCollection;
	
	public class SearchCommand implements Command, Responder
	{
		public function execute(p_event:CairngormEvent):void
		{
			DebugWindow.header();
			DebugWindow.debug("SearchCommand::execute, p_event.type: " + p_event.type);
				
			// we interogate the type because
			// Commands can support multiple events if you so choose
			switch(p_event.type)
			{
				case SearchBooksEvent.SEARCH_BOOKS:
					searchBooks(SearchBooksEvent(p_event).keywords);
					break;
			}
		}
		
		protected function searchBooks(p_keywords:String):void
		{
			ModelLocator.getInstance().search_state = ModelLocator.STATE_SEARCHING;
			getDelegate().searchBooks(p_keywords);
		}
		
		// These are default handlers.  Howerver, I suggest
		// you implement a pattern that uses something
		// like flash.net.Responder so you're Commands
		// can have multiple callbacks.  You just pass
		// those Responders as the first param to
		// the Delegate.
		public function onResult(event:*=null):void
		{
			DebugWindow.header();
			DebugWindow.debug("SearchCommand::onResult");
			
			var books:Array = ResultEvent(event).result as Array;
			DebugWindow.debug("books.length: " + books.length);
			ModelLocator.getInstance().books_array = new ArrayCollection(books);
			// update the state.  The View's who care (and thus are bound)
			// update when this value is changed.
			ModelLocator.getInstance().search_state = ModelLocator.STATE_DONE;
		}
		
		public function onFault(event:*=null):void
		{
			DebugWindow.header();
			DebugWindow.debug("SearchCommand::onFault");
			// update the state.  The View's who care (and thus are bound)
			// update when this value is changed.
			ModelLocator.getInstance().search_state = ModelLocator.STATE_DONE;
		}
		
		// for now this method seems dumb, but later, when you have
		// multiple command methods, they all call this.  Furthermore,
		// you can change it to support flash.net.Responders to allow
		// you can to forward Delegate responses to different handlers.
		protected function getDelegate():SearchDelegate
		{
			return new SearchDelegate(this);
		}
	}
}

