/*
	AmazonFactory
	version 2.0.0
	Created by Jesse R. Warden a.k.a. "JesterXL"
	jesterxl@jessewarden.com
	http://www.jessewarden.com
	
	Currently, this class just producers BookVO's;
	ValueObject classes which represent a "Book".
	Searches return a list of books.  This class
	takes that XML result, and creates a list
	of books.  A BookVO is way more portable
	and useful than raw XML.  Since it's strongly-typed,
	it uses little RAM, and allows it to be data bound as well.
	
	 This is release under a Creative Commons license. More information can be
    found here:
    
	http://creativecommons.org/licenses/by/2.5/
*/
package com.jxl.amazon.factories
{
	import com.jxl.amazon.vo.BookVO;
	
	public class AmazonFactory
	{
		// takes a chunk of XML, and makes a BookVO from it
		public static function buildBookFromXML(xml:XML):BookVO
		{
			var bookVO:BookVO = new BookVO();
			
			var ns1:Namespace = new Namespace("http://webservices.amazon.com/AWSECommerceService/2005-10-05");
			default xml namespace = ns1;
			
			bookVO.ASIN 						= xml.ASIN;
			bookVO.detailURL 					= xml.DetailPageURL;
			bookVO.smallImageURL 				= xml.SmallImage.URL;
			bookVO.smallImageHeight 			= xml.SmallImage.Height;
			bookVO.smallImageWidth 				= xml.SmallImage.Width;
			
			// some books have multiple authors, so need to handle
			// multiple Author nodes
			bookVO.author						= "";
			var count:int						= 0;
			for each(var auth:XML in xml.ItemAttributes.Author)
			{
				count++;
				bookVO.author 					+= auth + ", ";
			}
			
			if(count > 1)
				bookVO.author 					= bookVO.author.substring(0, bookVO.author.length - 2);
				
			bookVO.manufacturer					= xml.ItemAttributes.Manufacturer;
			bookVO.title						= xml.ItemAttributes.Title;
			
			return bookVO;
		}
		
		// takes the XML returned from the Amazon book search, 
		// and makes a list of BookVO's
		public static function buildArrayOfBooksFromXML(xml:XML):Array
		{
			DebugWindow.header();
			DebugWindow.debug("AmazonFactory::buildArrayOfBooksFromXML");
			var items_array:Array = [];
			
			var ns1:Namespace = new Namespace("http://webservices.amazon.com/AWSECommerceService/2005-10-05");
			default xml namespace = ns1;
			
			for each(var item:XML in xml.Items.Item)
			{
				var bookVO:BookVO = buildBookFromXML(item);
				DebugWindow.debug(bookVO);
				items_array.push(bookVO);
			}
			
			return items_array;
		}
	}
}